@@ -28,10 +28,9 @@ import (
 
 const (
 	DefaultWaitTimeout = 120 * time.Second
-	DefaultLeaseTtl    = 30 * time.Minute
+	DefaultLeaseTtl    = 13 * time.Second
 )
 
-// FIXME: move a lot of this stuff to internal/machine pkg... maybe all of it?
 type MachineDeployment interface {
 	DeployMachinesApp(context.Context) error
 }
@@ -73,6 +72,7 @@ type machineDeployment struct {
 	restartOnly                bool
 	waitTimeout                time.Duration
 	leaseTimeout               time.Duration
+	leaseDelayBetween          time.Duration
 }
 
 func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (MachineDeployment, error) {
@@ -90,9 +90,6 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 	if err != nil {
 		return nil, err
 	}
-	if len(appConfig.Statics) > 0 {
-		return nil, fmt.Errorf("error [statics] are not yet supported when deploying to machines; remove the [statics] section from fly.toml")
-	}
 	if args.AppCompact == nil {
 		return nil, fmt.Errorf("BUG: args.AppCompact should be set when calling this method")
 	}
@@ -115,8 +112,9 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 	if leaseTimeout == 0 {
 		leaseTimeout = DefaultLeaseTtl
 	}
+	leaseDelayBetween := (leaseTimeout - 1*time.Second) / 3
 	if waitTimeout != DefaultWaitTimeout || leaseTimeout != DefaultLeaseTtl || args.WaitTimeout == 0 || args.LeaseTimeout == 0 {
-		terminal.Infof("Using wait timeout: %s and lease timeout: %s\n", waitTimeout, leaseTimeout)
+		terminal.Infof("Using wait timeout: %s lease timeout: %s delay between lease refreshes: %s\n", waitTimeout, leaseTimeout, leaseDelayBetween)
 	}
 	processConfigs, err := appConfig.GetProcessConfigs()
 	if err != nil {
@@ -139,6 +137,7 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 		restartOnly:                args.RestartOnly,
 		waitTimeout:                waitTimeout,
 		leaseTimeout:               leaseTimeout,
+		leaseDelayBetween:          leaseDelayBetween,
 		releaseCommand:             releaseCmd,
 	}
 	err = md.setStrategy(args.Strategy)
@@ -233,6 +232,7 @@ func (md *machineDeployment) DeployMachinesApp(ctx context.Context) error {
 	if err != nil {
 		return err
 	}
+	md.machineSet.StartBackgroundLeaseRefresh(ctx, md.leaseTimeout, md.leaseDelayBetween)
 
 	// FIXME: handle deploy strategy: rolling, immediate, canary, bluegreen
 
@@ -608,6 +608,12 @@ func (md *machineDeployment) resolveUpdatedMachineConfig(origMachineRaw *api.Mac
 	launchInput.Config.Image = md.img.Tag
 	launchInput.Config.Metrics = md.appConfig.Metrics
 	launchInput.Config.Restart = origMachineRaw.Config.Restart
+	for _, s := range md.appConfig.Statics {
+		launchInput.Config.Statics = append(launchInput.Config.Statics, &api.Static{
+			GuestPath: s.GuestPath,
+			UrlPrefix: s.UrlPrefix,
+		})
+	}
 	launchInput.Config.Env = make(map[string]string)
 	for k, v := range md.appConfig.Env {
 		launchInput.Config.Env[k] = v
