@@ -11,6 +11,7 @@ import (
 	"path/filepath"
 	"regexp"
 	"strings"
+	"time"
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/logrusorgru/aurora"
@@ -91,6 +92,7 @@ func New() (cmd *cobra.Command) {
 func run(ctx context.Context) (err error) {
 	io := iostreams.FromContext(ctx)
 	client := client.FromContext(ctx).API()
+	colorize := io.ColorScheme()
 	workingDir := flag.GetString(ctx, "path")
 
 	// Determine the working directory
@@ -350,13 +352,73 @@ func run(ctx context.Context) (err error) {
 	if !(srcInfo == nil || srcInfo.SkipDatabase || flag.GetBool(ctx, "no-deploy") || flag.GetBool(ctx, "now")) {
 		confirmPg, err := prompt.Confirm(ctx, "Would you like to set up a Postgresql database now?")
 		if confirmPg && err == nil {
-			LaunchPostgres(ctx, appConfig.AppName, org, region)
+			db_app_name := fmt.Sprintf("%s-db", appConfig.AppName)
+			should_attach_db := false
+
+			if apps, err := client.GetApps(ctx, nil); err == nil {
+				for _, app := range apps {
+					if app.Name == db_app_name {
+						msg := fmt.Sprintf("We found an existing Postgresql database with the name %s. Would you like to attach it to your app?", app.Name)
+						confirmAttachPg, err := prompt.Confirm(ctx, msg)
+
+						if confirmAttachPg && err == nil {
+							should_attach_db = true
+
+						}
+
+					}
+
+				}
+
+			}
+
 			options["postgresql"] = true
+
+			if should_attach_db {
+				// If we try to attach to a PG cluster with the usual username
+				// format, we'll get an error (since that username already exists)
+				// by generating a new username with a sufficiently random number
+				// (in this case, the nanon second that the database is being attached)
+				current_time := time.Now().Nanosecond()
+				db_user := fmt.Sprintf("%s-%d", db_app_name, current_time)
+
+				err = postgres.AttachCluster(ctx, postgres.AttachParams{
+					PgAppName: db_app_name,
+					AppName:   appConfig.AppName,
+					DbUser:    db_user,
+				})
+
+				if err != nil {
+					msg := `Failed attaching %s to the Postgres cluster %s: %w.\nTry attaching manually with 'fly postgres attach --app %s %s'\n`
+					fmt.Fprintf(io.Out, msg, appConfig.AppName, db_app_name, err, appConfig.AppName, db_app_name)
+
+				} else {
+					fmt.Fprintf(io.Out, "Postgres cluster %s is now attached to %s\n", db_app_name, appConfig.AppName)
+				}
+
+			} else {
+				err := LaunchPostgres(ctx, appConfig.AppName, org, region)
+
+				if err != nil {
+					const msg = "Error creating Postgresql database. Be warned that this may affect deploys"
+					fmt.Fprintln(io.Out, colorize.Red(msg))
+
+				}
+
+			}
+
 		}
 
 		confirmRedis, err := prompt.Confirm(ctx, "Would you like to set up an Upstash Redis database now?")
 		if confirmRedis && err == nil {
-			LaunchRedis(ctx, appConfig.AppName, org, region)
+			err := LaunchRedis(ctx, appConfig.AppName, org, region)
+
+			if err != nil {
+				const msg = "Error creating Redis database. Be warned that this may affect deploys"
+				fmt.Fprintln(io.Out, colorize.Red(msg))
+
+			}
+
 			options["redis"] = true
 		}
 
@@ -491,6 +553,7 @@ func run(ctx context.Context) (err error) {
 	}
 	var v2AppConfig *appv2.Config
 	if deployArgs.ForceMachines {
+		appConfig.PrimaryRegion = region.Code
 		v2AppConfig, err = appv2.LoadConfig(configFilePath)
 		if err != nil {
 			return fmt.Errorf("invalid config: %w", err)
@@ -772,7 +835,7 @@ func determineDockerIgnore(ctx context.Context, workingDir string) (err error) {
 	return
 }
 
-func LaunchPostgres(ctx context.Context, appName string, org *api.Organization, region *api.Region) {
+func LaunchPostgres(ctx context.Context, appName string, org *api.Organization, region *api.Region) error {
 	io := iostreams.FromContext(ctx)
 	clusterAppName := appName + "-db"
 	err := postgres.CreateCluster(ctx, org, region,
@@ -784,7 +847,7 @@ func LaunchPostgres(ctx context.Context, appName string, org *api.Organization,
 		})
 
 	if err != nil {
-		fmt.Fprintf(io.Out, "Failed creating the Postgres cluster %s: %s", clusterAppName, err)
+		fmt.Fprintf(io.Out, "Failed creating the Postgres cluster %s: %s\n", clusterAppName, err)
 	} else {
 		err = postgres.AttachCluster(ctx, postgres.AttachParams{
 			PgAppName: clusterAppName,
@@ -792,16 +855,18 @@ func LaunchPostgres(ctx context.Context, appName string, org *api.Organization,
 		})
 
 		if err != nil {
-			msg := `Failed attaching %s to the Postgres cluster %s: %w.\nTry attaching manually with 'fly postgres attach --app %s %s'`
+			msg := `Failed attaching %s to the Postgres cluster %s: %w.\nTry attaching manually with 'fly postgres attach --app %s %s'\n`
 			fmt.Fprintf(io.Out, msg, appName, clusterAppName, err, appName, clusterAppName)
 
 		} else {
 			fmt.Fprintf(io.Out, "Postgres cluster %s is now attached to %s\n", clusterAppName, appName)
 		}
 	}
+
+	return err
 }
 
-func LaunchRedis(ctx context.Context, appName string, org *api.Organization, region *api.Region) {
+func LaunchRedis(ctx context.Context, appName string, org *api.Organization, region *api.Region) error {
 	name := appName + "-redis"
 	db, err := redis.Create(ctx, org, name, region, "", true, false)
 
@@ -810,4 +875,6 @@ func LaunchRedis(ctx context.Context, appName string, org *api.Organization, reg
 	} else {
 		redis.AttachDatabase(ctx, db, appName)
 	}
+
+	return err
 }
