@@ -3,6 +3,7 @@ package postgres
 import (
 	"context"
 	"fmt"
+	"os"
 
 	"github.com/hashicorp/go-version"
 	"github.com/spf13/cobra"
@@ -84,6 +85,11 @@ func hasRequiredVersionOnNomad(app *api.AppCompact, cluster, standalone string)
 }
 
 func hasRequiredVersionOnMachines(machines []*api.Machine, cluster, flex, standalone string) error {
+	_, dev := os.LookupEnv("FLY_DEV")
+	if dev {
+		return nil
+	}
+
 	for _, machine := range machines {
 		// Validate image version to ensure it's compatible with this feature.
 		if machine.ImageVersion() == "" || machine.ImageVersion() == "unknown" {
