@@ -7,10 +7,8 @@ import (
 	"bytes"
 	"context"
 	"crypto/ed25519"
-	"encoding/pem"
 	"fmt"
 	"io"
-	"math/rand"
 	"net"
 	"os"
 	"time"
@@ -18,8 +16,6 @@ import (
 	"github.com/briandowns/spinner"
 	"github.com/docker/docker/pkg/ioutils"
 	"github.com/pkg/errors"
-	sshCrypt "golang.org/x/crypto/ssh"
-
 	"github.com/superfly/flyctl/agent"
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/client"
@@ -100,7 +96,7 @@ func SSHConnect(p *SSHParams, addr string) error {
 		return fmt.Errorf("create ssh certificate: %w (if you haven't created a key for your org yet, try `flyctl ssh establish`)", err)
 	}
 
-	pemkey := marshalED25519PrivateKey(pk, "single-use certificate")
+	pemkey := ssh.MarshalED25519PrivateKey(pk, "single-use certificate")
 
 	terminal.Debugf("Keys for %s configured; connecting...\n", addr)
 
@@ -146,73 +142,6 @@ func SSHConnect(p *SSHParams, addr string) error {
 	return nil
 }
 
-// // stolen from `mikesmitty`, thanks, you are a mikesmitty and a scholar
-func marshalED25519PrivateKey(key ed25519.PrivateKey, comment string) []byte {
-	magic := append([]byte("openssh-key-v1"), 0)
-
-	var w struct {
-		CipherName   string
-		KdfName      string
-		KdfOpts      string
-		NumKeys      uint32
-		PubKey       []byte
-		PrivKeyBlock []byte
-	}
-
-	pk1 := struct {
-		Check1  uint32
-		Check2  uint32
-		Keytype string
-		Pub     []byte
-		Priv    []byte
-		Comment string
-		Pad     []byte `ssh:"rest"`
-	}{}
-
-	ci := rand.Uint32() // skipcq: GSC-G404
-	pk1.Check1 = ci
-	pk1.Check2 = ci
-
-	pk1.Keytype = sshCrypt.KeyAlgoED25519
-
-	pk := key.Public().(ed25519.PublicKey)
-	pubKey := []byte(pk)
-	pk1.Pub = pubKey
-	pk1.Priv = []byte(key)
-	pk1.Comment = comment
-
-	// Add some padding to match the encryption block size within PrivKeyBlock (without Pad field)
-	// 8 doesn't match the documentation, but that's what ssh-keygen uses for unencrypted keys. *shrug*
-	bs := 8
-	blockLen := len(sshCrypt.Marshal(pk1))
-	padLen := (bs - (blockLen % bs)) % bs
-	pk1.Pad = make([]byte, padLen)
-
-	for i := 0; i < padLen; i++ {
-		pk1.Pad[i] = byte(i + 1)
-	}
-
-	// Generate the pubkey prefix "\0\0\0\nssh-ed25519\0\0\0 "
-	prefix := []byte{0x0, 0x0, 0x0, 0x0b}
-	prefix = append(prefix, []byte(sshCrypt.KeyAlgoED25519)...)
-	prefix = append(prefix, []byte{0x0, 0x0, 0x0, 0x20}...)
-
-	w.CipherName = "none"
-	w.KdfName = "none"
-	w.KdfOpts = ""
-	w.NumKeys = 1
-	w.PubKey = append(w.PubKey, prefix...)
-	w.PubKey = append(w.PubKey, pubKey...)
-	w.PrivKeyBlock = sshCrypt.Marshal(pk1)
-
-	magic = append(magic, sshCrypt.Marshal(w)...)
-
-	return pem.EncodeToMemory(&pem.Block{
-		Type:  "OPENSSH PRIVATE KEY",
-		Bytes: magic,
-	})
-}
-
 func singleUseSSHCertificate(ctx context.Context, org api.OrganizationImpl) (*api.IssuedCertificate, ed25519.PrivateKey, error) {
 	client := client.FromContext(ctx).API()
 	hours := 1
