@@ -1,6 +1,6 @@
 package scanner
 
-func configurePython(sourceDir string) (*SourceInfo, error) {
+func configurePython(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
 	if !checksPass(sourceDir, fileExists("requirements.txt", "environment.yml")) {
 		return nil, nil
 	}
